**********************************
Built-in neuron types
**********************************

ANNarchy provides standard spiking neuron models, similar to the ones defined in PyNN (`http://neuralensemble.org/docs/PyNN/reference/neuronmodels.html <http://neuralensemble.org/docs/PyNN/reference/neuronmodels.html>`_).

.. contents::
   :local:

LeakyIntegrator
================

.. autodata:: ANNarchy.models.LeakyIntegrator

Izhikevich
================

.. autodata:: ANNarchy.models.Izhikevich

IF_curr_exp
================

.. autodata:: ANNarchy.models.IF_curr_exp

IF_cond_exp 
================

.. autodata:: ANNarchy.models.IF_cond_exp 

IF_curr_alpha
================

.. autodata:: ANNarchy.models.IF_curr_alpha

IF_cond_alpha 
================

.. autodata:: ANNarchy.models.IF_cond_alpha 

HH_cond_exp
================

.. autodata:: ANNarchy.models.HH_cond_exp

EIF_cond_exp_isfa_ista
========================

.. autodata:: ANNarchy.models.EIF_cond_exp_isfa_ista

EIF_cond_alpha_isfa_ista
=========================

.. autodata:: ANNarchy.models.EIF_cond_alpha_isfa_ista